==> ugene_1.12.3+dfsg.orig.tar.xz: ugene-1.12.3+dfsg.orig/src/plugins/dna_graphpack/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>U2::BaseContentGraphFactory</name>
    <message>
        <location filename="../src/BaseContentGraph.cpp" line="36"/>
        <source>ag_content_graph</source>
        <translation>AG содержание (%)</translation>
    </message>
    <message>
        <location filename="../src/BaseContentGraph.cpp" line="38"/>
        <source>gc_content_graph</source>
        <translation>GC содержание (%)</translation>
    </message>
</context>
<context>
    <name>U2::CumulativeSkewGraphFactory</name>
    <message>
        <location filename="../src/CumulativeSkew.cpp" line="39"/>
        <source>at_cumulative_skew_not_optimal_version</source>
        <translation>AT Cumulative Skew</translation>
    </message>
    <message>
        <location filename="../src/CumulativeSkew.cpp" line="41"/>
        <source>gc_cumulative_skew_not_optimal_version</source>
        <translation>GC Cumulative Skew</translation>
    </message>
</context>
<context>
    <name>U2::DNAGraphPackPlugin</name>
    <message>
        <source>dna_graphpack_plugin</source>
        <translation type="obsolete">DNA GraphPack</translation>
    </message>
    <message>
        <source>dna_graphpack_plugin_desc</source>
        <translation type="obsolete">Этот плагин содержит набор контекстных графиков для DNA последовательностей</translation>
    </message>
    <message>
        <location filename="../src/DNAGraphPackPlugin.cpp" line="51"/>
        <source>DNA Graph Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DNAGraphPackPlugin.cpp" line="52"/>
        <source>Contains a set of graphs for DNA sequences.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::DeviationGraphFactory</name>
    <message>
        <location filename="../src/DeviationGraph.cpp" line="35"/>
        <source>at_deviation_graph</source>
        <translation>AT отклонение (A-T)/(A+T)</translation>
    </message>
    <message>
        <location filename="../src/DeviationGraph.cpp" line="37"/>
        <source>gc_deviation_graph</source>
        <translation>GC отклонение (G-C)/(G+C)</translation>
    </message>
</context>
<context>
    <name>U2::EntropyGraphFactory</name>
    <message>
        <location filename="../src/EntropyAlgorithm.cpp" line="43"/>
        <source>informational_entropy</source>
        <translation>Информационная энтропия</translation>
    </message>
</context>
<context>
    <name>U2::GraphMenuAction</name>
    <message>
        <source>graph_menu</source>
        <translation type="obsolete">Графики</translation>
    </message>
</context>
<context>
    <name>U2::KarlinGraphFactory</name>
    <message>
        <location filename="../src/KarlinSignatureDifferenceGraph.cpp" line="37"/>
        <source>karlin_signature_difference_graph</source>
        <translation>Karlin Signature Difference</translation>
    </message>
</context>
</TS>

==> ugene_34.0+dfsg.orig.tar.xz: ugene-34.0/src/plugins/dna_graphpack/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>U2::BaseContentGraphFactory</name>
    <message>
        <location filename="../src/BaseContentGraph.cpp" line="38"/>
        <source>AG Content (%)</source>
        <translation>AG содержание (%)</translation>
    </message>
    <message>
        <location filename="../src/BaseContentGraph.cpp" line="40"/>
        <source>GC Content (%)</source>
        <translation>GC содержание (%)</translation>
    </message>
</context>
<context>
    <name>U2::CumulativeSkewGraphFactory</name>
    <message>
        <location filename="../src/CumulativeSkew.cpp" line="39"/>
        <source>AT Cumulative Skew</source>
        <translation>Суммарное смещение AT</translation>
    </message>
    <message>
        <location filename="../src/CumulativeSkew.cpp" line="41"/>
        <source>GC Cumulative Skew</source>
        <translation>Суммарное смещение GC</translation>
    </message>
</context>
<context>
    <name>U2::DNAGraphPackPlugin</name>
    <message>
        <location filename="../src/DNAGraphPackPlugin.cpp" line="52"/>
        <source>DNA/RNA Graph Package</source>
        <translation>Графический пакет ДНК/РНК</translation>
    </message>
    <message>
        <location filename="../src/DNAGraphPackPlugin.cpp" line="53"/>
        <source>Contains a set of graphs for DNA/RNA sequences.</source>
        <translation>Этот плагин содержит набор контекстных графиков для ДНК и РНК последовательностей.</translation>
    </message>
</context>
<context>
    <name>U2::DeviationGraphFactory</name>
    <message>
        <location filename="../src/DeviationGraph.cpp" line="35"/>
        <source>AT Deviation (A-T)/(A+T)</source>
        <translation>AT отклонение (A-T)/(A+T)</translation>
    </message>
    <message>
        <location filename="../src/DeviationGraph.cpp" line="37"/>
        <source>GC Deviation (G-C)/(G+C)</source>
        <translation>GC отклонение (G-C)/(G+C)</translation>
    </message>
</context>
<context>
    <name>U2::EntropyGraphFactory</name>
    <message>
        <location filename="../src/EntropyAlgorithm.cpp" line="43"/>
        <source>Informational Entropy</source>
        <translation>Информационная энтропия</translation>
    </message>
</context>
<context>
    <name>U2::KarlinGraphFactory</name>
    <message>
        <location filename="../src/KarlinSignatureDifferenceGraph.cpp" line="37"/>
        <source>Karlin Signature Difference</source>
        <translation>Различия Karlin Signature</translation>
    </message>
</context>
</TS>
